@@ -28,13 +28,17 @@ class Base(ABC):
         """
         pass
 
-    def formatResponse(self, original, resp, errorCode=0):
+    def formatResponse(self, original, resp, errorCode=0, errorWorker=None):
         """
             Metodo que se encarga de darle formato a la
             salida del procesamiento de la accion.
         """
         errorCode = int(errorCode)
+
         # Regresar la respuesta con el formato correcto
+        if not errorWorker is None:
+            pass
+
         resp = {
             "errorCode": errorCode,
             "response": {
@@ -51,7 +55,8 @@ class Base(ABC):
                     }
                 },
                 "uuid": original.get("uuid", None),
-            }
+            },
+            "errorWorker": errorWorker
         }
 
         # Retornar los datos
