@@ -54,7 +54,8 @@ class Fork(Base):
                 data['metadata']['bifurcacion'] = True
 
             if isError:
-                return self.formatResponse(data, None, self.getErrorCode(data))
+                # Retornar el mensaje correcto
+                return self.formatResponse(data, None, self.getErrorCode(data), self.getErrorMeta(data))
             elif nextFork is None:
                 # Parametros
                 paramsInject = self.getParams(span, data, params)
@@ -248,6 +249,22 @@ class Fork(Base):
         else:
             return errorCode
 
+    def getErrorMeta(self, data):
+        """
+        Metodo para recuperar la meta data de los errore.
+
+        Arguments:
+            data object -- Datos de la repuesta
+        """
+        # Recuperar todo el objeto de error.
+        errorCode = getItemBy('response.data.response.errorCode', data)
+
+        # Validar que sea un error y no un dato correcto.
+        if errorCode is None:
+            return None
+        else:
+            return getItemBy('response.data.response', data)
+
     def changeMetadata(self, data, current):
         """
             Metodo apra aplicar los cambios sobre la metadata
