@@ -400,7 +400,7 @@ class Microservices(BaseClass, ABC):
             errorCode = errorResp.get('errorCode', -99)  # Error generico
 
         # Validar si ocurrio un error
-        if errorCode < 0:
+        if errorCode < 0 or errorCode > 0:
             # Estructura del mensaje de error
             dataResponse['response'] = {
                 "data": {
